<?php

namespace Hospital\Econsultation\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Hospital\Econsultation\Interfaces\EconsultationRepositoryInterface;

class EconsultationPublicController extends BaseController
{
    // use EconsultationWorkflow;

    /**
     * Constructor.
     *
     * @param type \Hospital\Econsultation\Interfaces\EconsultationRepositoryInterface $econsultation
     *
     * @return type
     */
    public function __construct(EconsultationRepositoryInterface $econsultation)
    {
        $this->repository = $econsultation;
        parent::__construct();
    }

    /**
     * Show econsultation's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $econsultations = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$econsultation::$econsultation.names'))
            ->view('$econsultation::public.econsultation.index')
            ->data(compact('$econsultations'))
            ->output();
    }

    /**
     * Show econsultation's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $econsultations = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$econsultation::$econsultation.names'))
            ->view('$econsultation::public.econsultation.index')
            ->data(compact('$econsultations'))
            ->output();
    }

    /**
     * Show econsultation.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $econsultation = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$econsultation->name . trans('$econsultation::$econsultation.name'))
            ->view('$econsultation::public.econsultation.show')
            ->data(compact('$econsultation'))
            ->output();
    }

}
