<?php

namespace Hospital\Econsultation\Policies;

use Litepie\User\Contracts\UserPolicy;
use Hospital\Econsultation\Models\Econsultation;

class EconsultationPolicy
{

    /**
     * Determine if the given user can view the econsultation.
     *
     * @param UserPolicy $user
     * @param Econsultation $econsultation
     *
     * @return bool
     */
    public function view(UserPolicy $user, Econsultation $econsultation)
    {
        if ($user->canDo('econsultation.econsultation.view') && $user->isAdmin()) {
            return true;
        }

        return $econsultation->user_id == user_id() && $econsultation->user_type == user_type();
    }

    /**
     * Determine if the given user can create a econsultation.
     *
     * @param UserPolicy $user
     * @param Econsultation $econsultation
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('econsultation.econsultation.create');
    }

    /**
     * Determine if the given user can update the given econsultation.
     *
     * @param UserPolicy $user
     * @param Econsultation $econsultation
     *
     * @return bool
     */
    public function update(UserPolicy $user, Econsultation $econsultation)
    {
        if ($user->canDo('econsultation.econsultation.edit') && $user->isAdmin()) {
            return true;
        }

        return $econsultation->user_id == user_id() && $econsultation->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given econsultation.
     *
     * @param UserPolicy $user
     * @param Econsultation $econsultation
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Econsultation $econsultation)
    {
        return $econsultation->user_id == user_id() && $econsultation->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given econsultation.
     *
     * @param UserPolicy $user
     * @param Econsultation $econsultation
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Econsultation $econsultation)
    {
        if ($user->canDo('econsultation.econsultation.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given econsultation.
     *
     * @param UserPolicy $user
     * @param Econsultation $econsultation
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Econsultation $econsultation)
    {
        if ($user->canDo('econsultation.econsultation.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
